@@ -1,7 +1,7 @@
 /* Focus Blur -- blur with focus plug-in.
  * Copyright (C) 2002-2008 Kyoichiro Suda
  *
- * The GIMP -- an image manipulation program
+ * GIMP - The GNU Image Manipulation Program
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
  *
  * This program is free software; you can redistribute it and/or modify
@@ -125,7 +125,7 @@ focusblur_dialog (FblurParam *param)
   gint           row;
   gboolean       run;
 
-  gimp_ui_init (PLUG_IN_BINARY, TRUE);
+  gimp_ui_init (PLUG_IN_BINARY, FALSE);
   focusblur_stock_init ();
 
   /* Main dialogue */
